@@ -217,6 +217,24 @@ class GridMapTests(TestCase):
         map3 = GridMap((32, 32), (8, 8), names)
         self.assertEqual(names, map3.names)
 
+    def test_css(self):
+        map2 = GridMap((0, 96, 32, 128), (16, 16), ['whiskey', 'x-ray', 'yankee', 'zulu'])
+        self.assertEqual("width: 16px; height: 16px; background-position: 0 -96px;", map2.get_css('whiskey'))
+        self.assertEqual("width: 16px; height: 16px; background-position: -16px -96px;", map2.get_css('x-ray'))
+        self.assertEqual("width: 16px; height: 16px; background-position: 0 -112px;", map2.get_css('yankee'))
+        self.assertEqual("width: 16px; height: 16px; background-position: -16px -112px;", map2.get_css('zulu'))
+
+    def test_css_scaled(self):
+        map2 = GridMap((0, 96, 32, 128), (16, 16), ['whiskey', 'x-ray', 'yankee', 'zulu'])
+        self.assertEqual("width: 16px; height: 16px; background-position: 0 -96px;", map2.get_css('whiskey', 16))
+        self.assertEqual("width: 16px; height: 16px; background-position: -16px -96px;", map2.get_css('x-ray', 16))
+        self.assertEqual("width: 16px; height: 16px; background-position: 0 -112px;", map2.get_css('yankee', 16))
+        self.assertEqual("width: 16px; height: 16px; background-position: -16px -112px;", map2.get_css('zulu', 16))
+        self.assertEqual("background-size: 64px 64px; width: 32px; height: 32px; background-position: 0 -192px;", map2.get_css('whiskey', 32))
+        self.assertEqual("background-size: 64px 64px; width: 32px; height: 32px; background-position: -32px -192px;", map2.get_css('x-ray', 32))
+        self.assertEqual("background-size: 64px 64px; width: 32px; height: 32px; background-position: 0 -224px;", map2.get_css('yankee', 32))
+        self.assertEqual("background-size: 64px 64px; width: 32px; height: 32px; background-position: -32px -224px;", map2.get_css('zulu', 32))
+
 class CompositeMapTests(TestCase):
     def test_two_grids(self):
         names1 = [
