@@ -673,13 +673,39 @@ class MapBase(object):
 
         return sorted((cn, sorted(ns.values())) for (cn, ns) in groups.items())
 
+    def get_css(self, name, desired_width=None):
+        """Returns a CSS style directive to display this cell.
+
+        Arguments --
+            name -- names a cell in the map
+            desired_width (optional) -- how wide the tile should be
+                (requires CSS3)
+
+        Gives settings for width, height, and background-positions.
+        If desired_width is specified and differs from the natural width
+        of the cell, then background-size is also specified.
+
+        Assumes something else supplies background-image
+        and background-repeat: no-repeat;
+        """
+        left, top, right, bottom = self.get_box(name)
+        scale = float(desired_width) / (right - left) if desired_width else 1
+        if scale == 1:
+            dimens = ['{0}px'.format(x) if x else '0' for x in [right - left, bottom - top, -left, -top]]
+            return 'width: {0}; height: {1}; background-position: {2} {3};'.format(*dimens)
+
+        width, height = self.get_css_background_dimens()
+
+        dimens = ['{0}px'.format(x * scale).replace('.0', '') if x else '0' for x in [width, height, right - left, bottom - top, -left, -top]]
+        return 'background-size: {0} {1}; width: {2}; height: {3}; background-position: {4} {5};'.format(*dimens)
+
 
 class NotInMap(Exception):
     def __init__(self, name, map):
         super(NotInMap, self).__init__('{0!r} not found in map (must be one of {1})'.format(
             name, ', '.join(map.names)))
         self.name = name
-        self.maop = map
+        self.map = map
 
 class GridMap(MapBase):
     def __init__(self, source_box, cell_box, names):
@@ -706,6 +732,9 @@ class GridMap(MapBase):
 
         self.names = names
 
+    def get_css_background_dimens(self):
+        return self.nx * self.cell_wd, self.ny * self.cell_ht
+
     def get_box(self, name):
         try:
             i = self.names.index(name)
